@@ -15,7 +15,8 @@ class DownloadSources(Enum):
     morningstar = auto(),
     morningstar_de = auto(),
     reuters = auto(),
-    vanguard_au = auto()
+    vanguard_au = auto(),
+    yahoo_finance = auto()
 
 
 class Quote:
@@ -25,6 +26,7 @@ class Quote:
     The list of sources is available through q.sources property.
     """
     symbol = None
+    exchange = None
     source = None
     _currency = None
 
@@ -85,7 +87,7 @@ class Quote:
         """ Set the download source to use to fetch the prices. """
         self.source = source.lower()
 
-    def __download(self, namespace: str, symbol: str, currency: str = None, source: str = None):
+    def __download(self, exchange: str, symbol: str, currency: str = None, source: str = None):
         """ Download single latest price """
         from pricedb import SecuritySymbol
         from .alphavantage import AlphaVantageDownloader
@@ -93,14 +95,15 @@ class Quote:
         from .morningstar_de import MorningstarDeDownloader
         from .vanguard_au import VanguardAuDownloader
         from .boerse_frankfurt import FwbDownloader
+        from .yahoo_finance import YahooFinanceDownloader
         from .fixerio import Fixerio
         from .reuters import Reuters
 
         assert source is not None
         assert isinstance(source, str)
 
-        if namespace:
-            namespace = namespace.upper()
+        if exchange:
+            exchange = exchange.upper()
         symbol = symbol.upper()
         if currency:
             currency = currency.upper()
@@ -111,7 +114,7 @@ class Quote:
         security_symbol = SecuritySymbol("", "")
         security_symbol.parse(symbol)
         if not security_symbol.namespace:
-            security_symbol.namespace = namespace
+            security_symbol.namespace = exchange
 
         # todo: read import modules dynamically?
 
@@ -129,6 +132,8 @@ class Quote:
             actor = FwbDownloader()
         elif source == DownloadSources.reuters.name:
             actor = Reuters()
+        elif source == DownloadSources.yahoo_finance.name:
+            actor = YahooFinanceDownloader()
         else:
             raise ValueError("No source specified for price download.")
 
